@@ -26,6 +26,7 @@
 Tests for the WorkflowManager
 """
 
+import os
 from subprocess import CalledProcessError
 from unittest import TestCase, TestLoader
 import mock
@@ -41,8 +42,10 @@ from vis.analyzers.indexers import noterest, lilypond
 # pylint: disable=C0111
 class WorkflowTests(TestCase):
     # NB: this class is just for __init__(), load(), and run() (without the run() helper methods)
-    def test_init_1(self):
+    @mock.patch('vis.workflow.path.join', return_value='/some/vis/path.r')
+    def test_init_1(self, mock_join):
         # with a list of basestrings
+        # NB: mocked out os.path.join()
         with mock.patch(u'vis.models.indexed_piece.IndexedPiece') as mock_ip:
             in_val = [u'help.txt', 'path.xml', u'why_you_do_this.rtf']
             test_wc = WorkflowManager(in_val)
@@ -63,9 +66,14 @@ class WorkflowTests(TestCase):
                             u'interval quality': False, u'simple intervals': False,
                             u'include rests': False, u'count frequency': True}
             self.assertEqual(exp_sh_setts, test_wc._shared_settings)
+            self.assertEqual(1, mock_join.call_count)
 
-    def test_init_2(self):
+    @mock.patch('vis.workflow.vis')
+    def test_init_2(self, mock_vis):
         # with a list of IndexedPieces
+        # NB: mocked out vis
+        mock_vis.__path__ = ['/some/path/']
+        exp_chart_path = '/some/path/scripts/R_bar_chart.r'
         in_val = [IndexedPiece(u'help.txt'), IndexedPiece('path.xml'),
                   IndexedPiece(u'why_you_do_this.rtf')]
         test_wc = WorkflowManager(in_val)
@@ -82,9 +90,11 @@ class WorkflowTests(TestCase):
                         u'interval quality': False, u'simple intervals': False,
                         u'include rests': False, u'count frequency': True}
         self.assertEqual(exp_sh_setts, test_wc._shared_settings)
+        self.assertEqual(exp_chart_path, test_wc._R_bar_chart_path)
 
     def test_init_3(self):
         # with a mixed list of valid things
+        # NB: ensure the _R_bar_chart_path actually exists
         in_val = [IndexedPiece(u'help.txt'), 'path.xml', u'why_you_do_this.rtf']
         test_wc = WorkflowManager(in_val)
         self.assertEqual(3, len(test_wc._data))
@@ -101,6 +111,7 @@ class WorkflowTests(TestCase):
                         u'interval quality': False, u'simple intervals': False,
                         u'include rests': False, u'count frequency': True}
         self.assertEqual(exp_sh_setts, test_wc._shared_settings)
+        self.assertTrue(os.path.exists(test_wc._R_bar_chart_path))
 
     def test_init_4(self):
         # with mostly basestrings but a few ints
@@ -272,10 +283,11 @@ class Output(TestCase):
         self.assertRaises(RuntimeError, test_wc.output, u'R histogram')
 
 
+@mock.patch('vis.workflow.path.join', return_value='hello')
+@mock.patch(u'vis.workflow.WorkflowManager._get_dataframe')
+@mock.patch(u'subprocess.check_output')
 class MakeHistogram(TestCase):
-    @mock.patch(u'vis.workflow.WorkflowManager._get_dataframe')
-    @mock.patch(u'subprocess.check_output')
-    def test_histogram_1(self, mock_call, mock_gdf):
+    def test_histogram_1(self, mock_call, mock_gdf, mock_join):
         # with specified pathname; last experiment was intervals with 20 pieces; self._result is DF
         test_wc = WorkflowManager([])
         test_wc._previous_exp = u'intervals'
@@ -284,14 +296,13 @@ class MakeHistogram(TestCase):
         path = u'pathname!'
         actual = test_wc._make_histogram(path)
         self.assertEqual(0, mock_gdf.call_count)
-        expected_args = [u'Rscript', u'--vanilla', WorkflowManager._R_bar_chart_path,
+        expected_args = [u'Rscript', u'--vanilla', mock_join.return_value,
                          path + u'.dta', path + u'.png', u'int', u'20']
         mock_call.assert_called_once_with(expected_args)
         self.assertEqual(path + u'.png', actual)
+        self.assertEqual(1, mock_join.call_count)
 
-    @mock.patch(u'vis.workflow.WorkflowManager._get_dataframe')
-    @mock.patch(u'subprocess.check_output')
-    def test_histogram_2(self, mock_call, mock_gdf):
+    def test_histogram_2(self, mock_call, mock_gdf, mock_join):
         # with unspecified pathname; last experiment was 14-grams with 1 piece; self._result is S
         test_wc = WorkflowManager([])
         test_wc._previous_exp = u'n-grams'
@@ -301,14 +312,13 @@ class MakeHistogram(TestCase):
         path = u'test_output/output_result'
         actual = test_wc._make_histogram()
         mock_gdf.assert_called_once_with(u'freq', None, None)
-        expected_args = [u'Rscript', u'--vanilla', WorkflowManager._R_bar_chart_path,
+        expected_args = [u'Rscript', u'--vanilla', mock_join.return_value,
                          path + u'.dta', path + u'.png', u'14', u'1']
         mock_call.assert_called_once_with(expected_args)
         self.assertEqual(path + u'.png', actual)
+        self.assertEqual(1, mock_join.call_count)
 
-    @mock.patch(u'vis.workflow.WorkflowManager._get_dataframe')
-    @mock.patch(u'subprocess.check_output')
-    def test_histogram_3(self, mock_call, mock_gdf):
+    def test_histogram_3(self, mock_call, mock_gdf, mock_join):
         # test_ouput_6, plus top_x and threshold
         test_wc = WorkflowManager([])
         test_wc._previous_exp = u'n-grams'
@@ -318,14 +328,13 @@ class MakeHistogram(TestCase):
         path = u'test_output/output_result'
         actual = test_wc._make_histogram(top_x=420, threshold=1987)
         mock_gdf.assert_called_once_with(u'freq', 420, 1987)
-        expected_args = [u'Rscript', u'--vanilla', WorkflowManager._R_bar_chart_path,
+        expected_args = [u'Rscript', u'--vanilla', mock_join.return_value,
                          path + u'.dta', path + u'.png', u'14', u'1']
         mock_call.assert_called_once_with(expected_args)
         self.assertEqual(path + u'.png', actual)
+        self.assertEqual(1, mock_join.call_count)
 
-    @mock.patch(u'vis.workflow.WorkflowManager._get_dataframe')
-    @mock.patch(u'subprocess.check_output')
-    def test_histogram_4(self, mock_call, mock_gdf):
+    def test_histogram_4(self, mock_call, mock_gdf, mock_join):
         # test_output_4() but the subprocess thing fails
         def raiser(*args):
             raise CalledProcessError(u'Bach!', 42, u'CPE')
@@ -343,9 +352,10 @@ class MakeHistogram(TestCase):
             actual = run_e
         self.assertEqual(expected_msg, actual.message)
         self.assertEqual(0, mock_gdf.call_count)
-        expected_args = [u'Rscript', u'--vanilla', WorkflowManager._R_bar_chart_path,
+        expected_args = [u'Rscript', u'--vanilla', mock_join.return_value,
                          path + u'.dta', path + u'.png', u'int', u'20']
         mock_call.assert_called_once_with(expected_args)
+        self.assertEqual(1, mock_join.call_count)
 
 
 class MakeLilyPond(TestCase):
@@ -360,7 +370,7 @@ class MakeLilyPond(TestCase):
         try:
             test_wm._make_lilypond(['paths'])
         except RuntimeError as the_err:
-            self.assertEqual(WorkflowManager._count_frequency_message, the_err.message)
+            self.assertEqual(WorkflowManager._COUNT_FREQUENCY_MESSAGE, the_err.message)
 
     def test_lilypond_1b(self):
         # error conditions: if the lengths are different, (but 'count frequency' is okay)
@@ -372,7 +382,7 @@ class MakeLilyPond(TestCase):
         try:
             test_wm._make_lilypond(['paths'])
         except RuntimeError as the_err:
-            self.assertEqual(WorkflowManager._count_frequency_message, the_err.message)
+            self.assertEqual(WorkflowManager._COUNT_FREQUENCY_MESSAGE, the_err.message)
 
     @mock.patch(u'vis.models.indexed_piece.IndexedPiece', spec_set=IndexedPiece)
     def test_lilypond_2(self, test_ip):
@@ -394,7 +404,7 @@ class MakeLilyPond(TestCase):
         test_wm._result = exp_results
         test_wm.settings(None, 'count frequency', False)
         test_wm.settings(0, 'voice combinations', '[[0]]')
-        exp_part_labels = [{'part_names': [[0]]}]
+        #exp_part_labels = [{'part_names': [[0]]}]
         # 2: run
         test_wm._make_lilypond(input_path)
         # 3: check
@@ -405,7 +415,9 @@ class MakeLilyPond(TestCase):
         for i, piece in enumerate(test_wm._data):
             self.assertEqual(num_parts + 1, piece.get_data.call_count)
             for j in xrange(num_parts):
-                piece.get_data.assert_any_call(lily_ind_list, exp_part_labels[i], [exp_results[i][j]])
+                piece.get_data.assert_any_call(lily_ind_list,
+                                               None,  # {'part_names': exp_part_labels[i]},
+                                               [exp_results[i][j]])
             sett_dict = {u'run_lilypond': True,
                          u'output_pathname': input_path + '.ly',
                          u'annotation_part': [get_data_ret(0, 0, [z])[0] for z in exp_results[i]]}
@@ -433,7 +445,7 @@ class MakeLilyPond(TestCase):
         test_wm._result = exp_results
         test_wm.settings(None, 'count frequency', False)
         test_wm.settings(0, 'voice combinations', 'all pairs')
-        exp_part_labels = [[[0, 1], [0, 2], [1, 2]]]
+        #exp_part_labels = [[[0, 1], [0, 2], [1, 2]]]
         # 2: run
         test_wm._make_lilypond(input_path)
         # 3: check
@@ -445,7 +457,7 @@ class MakeLilyPond(TestCase):
             self.assertEqual(num_parts + 1, piece.get_data.call_count)
             for j in xrange(num_parts):
                 piece.get_data.assert_any_call(lily_ind_list,
-                                               {'part_names': exp_part_labels[i]},
+                                               None,  # {'part_names': exp_part_labels[i]},
                                                [exp_results[i][j]])
             sett_dict = {u'run_lilypond': True,
                          u'output_pathname': input_path + '.ly',
@@ -476,7 +488,7 @@ class MakeLilyPond(TestCase):
         test_wm.settings(0, 'voice combinations', 'all')
         test_wm.settings(1, 'voice combinations', 'all')
         test_wm.settings(2, 'voice combinations', 'all')
-        exp_part_labels = [[[0, 2], [1, 2]] for _ in xrange(len(piece_list))]
+        #exp_part_labels = [[[0, 2], [1, 2]] for _ in xrange(len(piece_list))]
         # 2: run
         test_wm._make_lilypond(input_path)
         # 3: check
@@ -488,7 +500,7 @@ class MakeLilyPond(TestCase):
             self.assertEqual(num_parts + 1, piece.get_data.call_count)
             for j in xrange(num_parts):
                 piece.get_data.assert_any_call(lily_ind_list,
-                                               {'part_names': exp_part_labels[j]},
+                                               None,  # {'part_names': exp_part_labels[j]},
                                                [exp_results[i][j]])
             # NB: the output_pathname is different from the previous two tests
             sett_dict = {u'run_lilypond': True,
