@@ -30,9 +30,11 @@ analysis patterns for counterpoint. The :class:`TemplateWorkflow` class is a tem
 new ``WorkflowManager`` classes.
 """
 
+from os import path
 import ast
 import subprocess
 import pandas
+import vis
 from vis.models import indexed_piece
 from vis.models.aggregated_pieces import AggregatedPieces
 from vis.analyzers.indexers import noterest, interval, ngram, offset, repeat, lilypond
@@ -76,9 +78,7 @@ class WorkflowManager(object):
     # - self._shared_settings: settings shared among all piecesd
     # - self._previous_exp: name of the experiments whose results are stored in self._result
     # - self._loaded: whether the load() method has been called
-
-    # path to the R-language script that makes bar charts
-    _R_bar_chart_path = u'scripts/R_bar_chart.r'
+    # - self._R_bar_chart_path: path to the R-language script that makes bar charts
 
     # names of the experiments available through run()
     # NOTE: do not re-order these, or run() will break
@@ -86,9 +86,12 @@ class WorkflowManager(object):
 
     # Error message when users call output() with LilyPond, but they probably called run() with
     # ``count frequency`` set to True.
-    _count_frequency_message = u'LilyPond output is not possible after you call run() with ' + \
+    _COUNT_FREQUENCY_MESSAGE = u'LilyPond output is not possible after you call run() with ' + \
         '"count frequency" set to True.'
 
+    # The error when we required two-voice pairs, but one of the combinations wasn't a pair.
+    _REQUIRE_PAIRS_ERROR = u'All voice combinations must have two parts (found %s).'
+
     def __init__(self, pathnames):
         # create the list of IndexedPiece objects
         self._data = []
@@ -114,6 +117,8 @@ class WorkflowManager(object):
         self._previous_exp = None
         # whether the load() method has been called
         self._loaded = False
+        # calculate the bar chart script's path
+        self._R_bar_chart_path = path.join(vis.__path__[0], 'scripts', 'R_bar_chart.r')
 
     def __len__(self):
         """
@@ -451,6 +456,10 @@ class WorkflowManager(object):
             combos = unicode(self.settings(i, u'voice combinations'))
             if combos != u'all' and combos != u'all pairs' and combos != u'None':
                 combos = ast.literal_eval(combos)
+                # ensure each combination is a two-voice pair
+                for pair in combos:
+                    if 2 != len(pair):
+                        raise RuntimeError(WorkflowManager._REQUIRE_PAIRS_ERROR % len(pair))
                 vert_ints = WorkflowManager._remove_extra_pairs(vert_ints, combos)
             # we no longer need to know the combinations' names, so we can make a list
             vert_ints = list(vert_ints.itervalues())
@@ -459,7 +468,6 @@ class WorkflowManager(object):
             # remove the "Rest" entries, if required
             if self.settings(None, u'include rests') is not True:
                 # we'll just get a view that omits the "Rest" entries in the Series
-                # TODO: this is pandas magic; check it for 0.13
                 for i, pair in enumerate(post):
                     post[i] = pair[pair != u'Rest']
             self._result.append(post)
@@ -671,8 +679,8 @@ class WorkflowManager(object):
             token = unicode(self.settings(None, u'n'))
         else:
             token = u'things'
-        call_to_r = [u'Rscript', u'--vanilla', WorkflowManager._R_bar_chart_path,
-                        stata_path, png_path, token, str(len(self._data))]
+        call_to_r = [u'Rscript', u'--vanilla', self._R_bar_chart_path,
+                     stata_path, png_path, token, str(len(self._data))]
         try:
             subprocess.check_output(call_to_r)
         except subprocess.CalledProcessError as cpe:
@@ -688,7 +696,7 @@ class WorkflowManager(object):
         """
         # try to determine whether they called run() properly (``count frequency`` should be False)
         if self.settings(None, 'count frequency') is True or len(self._data) != len(self._result):
-            raise RuntimeError(WorkflowManager._count_frequency_message)
+            raise RuntimeError(WorkflowManager._COUNT_FREQUENCY_MESSAGE)
         pathname = u'test_output/output_result' if pathname is None else unicode(pathname)
         # the file extension for LilyPond
         file_ext = u'.ly'
@@ -710,11 +718,10 @@ class WorkflowManager(object):
             else:
                 combos = ast.literal_eval(self.settings(i, 'voice combinations'))
             for j in xrange(len(self._result[i])):
-                setts = {'part_names': combos}
                 ann_p.append(self._data[i].get_data([lilypond.AnnotationIndexer,
                                                      lilypond.AnnotateTheNoteIndexer,
                                                      lilypond.PartNotesIndexer],
-                                                    setts,
+                                                    None,
                                                     [self._result[i][j]])[0])
             annotation_parts.append(ann_p)
         # run OutputLilyPond and LilyPond
